@@ -1,7 +1,7 @@
 /* events.c
 
 Copyright (C) 1999-2003 Tom Gilbert.
-Copyright (C) 2010-2020 Birte Kristina Friesel.
+Copyright (C) 2010-2024 Birte Kristina Friesel.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -366,9 +366,12 @@ static void feh_event_handle_ButtonRelease(XEvent * ev)
 		} else if (opt.mode == MODE_NEXT) {
 			opt.mode = MODE_NORMAL;
 			winwid->mode = MODE_NORMAL;
-			if (winwid->type == WIN_TYPE_SLIDESHOW)
-				slideshow_change_image(winwid, SLIDE_NEXT, 1);
-			else if (winwid->type == WIN_TYPE_THUMBNAIL) {
+			if (winwid->type == WIN_TYPE_SLIDESHOW) {
+				if (opt.tap_zones && ev->xbutton.x < winwid->w / 2)
+					slideshow_change_image(winwid, SLIDE_PREV, 1);
+				else
+					slideshow_change_image(winwid, SLIDE_NEXT, 1);
+			} else if (winwid->type == WIN_TYPE_THUMBNAIL) {
 				feh_file *thumbfile;
 				int x, y;
 
