@@ -1,7 +1,7 @@
 /* options.c
 
 Copyright (C) 1999-2003 Tom Gilbert.
-Copyright (C) 2010-2020 Birte Kristina Friesel.
+Copyright (C) 2010-2024 Birte Kristina Friesel.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -419,6 +419,7 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		{"no-xinerama"   , 0, 0, OPTION_no_xinerama},
 		{"draw-tinted"   , 0, 0, OPTION_draw_tinted},
 		{"info"          , 1, 0, OPTION_info},
+		{"tap-zones"     , 0, 0, OPTION_tap_zones},
 		{"force-aliasing", 0, 0, OPTION_force_aliasing},
 		{"no-fehbg"      , 0, 0, OPTION_no_fehbg},
 		{"keep-zoom-vp"  , 0, 0, OPTION_keep_zoom_vp},
@@ -783,6 +784,9 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 				opt.draw_info = 1;
 			}
 			break;
+		case OPTION_tap_zones:
+			opt.tap_zones = 1;
+			break;
 		case OPTION_force_aliasing:
 			opt.force_aliasing = 1;
 			break;
